# yaledirectory [![PyPI version](https://badge.fury.io/py/yaledirectory.svg)](https://badge.fury.io/py/yaledirectory)

> Python library for interfacing with the undocumented Yale Directory API.

[API documentation](https://developers.yale.edu/directory)

## Setup
First, install the module:

```sh
pip3 install yaledirectory
```

Then, to use these functions, you must import the module:

```py
import yaledirectory
```

Before using the library, you must instantiate its class, for example:

```py
directory = yaledirectory.YaleDirectory()
```

## Retrieval Functions
- TODO

See `example.py` for several usage examples.

## Author
[Erik Boesen](https://github.com/ErikBoesen)

## License
[GPL](LICENSE)
